# Blender 2.9 script to import and render (ParaView-) x3d objects.
# Scene is assumed to include camera, lights, and mesh object named Cube.
# Cube material will be copied to the imported object. 
# Current settings are used for rendering.

import bpy

for number in range(1,4):

    meshpath="C:\Blender_course\paraview_isosurface_""%02d"".x3d" % number
    imagepath="C:\Blender_course\paraview_image_""%02d""" % number

# Import X3D objects
    bpy.ops.import_scene.x3d(filepath=meshpath, axis_forward='Y', axis_up='Z')

# Delete imported lamp and camera
    bpy.ops.object.select_pattern(pattern="Direct*", extend=False)
    bpy.ops.object.select_pattern(pattern="View*", extend=True)
    bpy.ops.object.delete()

# Scale and smooth
    bpy.ops.object.select_pattern(pattern="Shape*", extend=False)
    bpy.ops.transform.resize(value=(0.2, 0.2, 0.2))
    bpy.ops.object.shade_smooth()

# Link material from Cube
    bpy.ops.object.select_pattern(pattern="Shape*", extend=False)
    bpy.ops.object.select_pattern(pattern="Cube", extend=True)
    bpy.context.view_layer.objects.active = bpy.context.scene.objects["Cube"]
    bpy.ops.object.make_links_data(type='MATERIAL')

# Render image
    bpy.context.scene.render.image_settings.file_format = 'JPEG'
    bpy.context.scene.render.filepath = imagepath
    bpy.ops.render.render(write_still=True)

# Delete Shape
    bpy.ops.object.select_pattern(pattern="Shape*", extend=False)
    bpy.ops.object.delete()

# Housekeeping, delete orphan meshes to save memory
    for block in bpy.data.meshes:
        if block.users == 0:
            bpy.data.meshes.remove(block)